==> general_lib-0.0.28.tar.gz: lib/generate/generate_core.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names

import 'dart:math';

import 'package:general_lib/general_lib.dart';

class GenerateSecretWords {
  int min_count;
  int max_count;
  GenerateSecretWords({
    required this.min_count,
    required this.max_count,
  });

  static GenerateSecretWords minMax({
    required int minCount,
    required int maxCount,
  }) {
    return GenerateSecretWords(
      min_count: minCount,
      max_count: maxCount,
    );
  }

  static GenerateSecretWords fixed({required int totalCount}) {
    return GenerateSecretWords(
      max_count: totalCount,
      min_count: totalCount,
    );
  }

  int totalLength() {
    if (min_count == max_count) {
      return min_count;
    }
    return Random().nextInt(max_count - min_count + 1) + min_count;
  }
}

class Generate {
  Generate();

  static List<String> secretRandomWords({
    required int totalCount,
    required GenerateSecretWords generateSecretWords,
    String schema = "0123456789abcdefghijklmnopqrstuvwxyz",
  }) {
    List<String> secretWords = [];

    while (true) {
      if (secretWords.length == totalCount) {
        return secretWords;
      } else {
        String randomWord = generateUuid(generateSecretWords.totalLength(), text: schema);
        if (!secretWords.contains(randomWord)) {
          secretWords.add(randomWord);
        }
      }
    }
  }
}

==> general_lib-0.0.30.tar.gz: lib/generate/generate_core.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names

import 'dart:math';

import 'package:general_lib/general_lib.dart';

class GenerateSecretWords {
  int min_count;
  int max_count;
  GenerateSecretWords({
    required this.min_count,
    required this.max_count,
  });

  static GenerateSecretWords minMax({
    required int minCount,
    required int maxCount,
  }) {
    return GenerateSecretWords(
      min_count: minCount,
      max_count: maxCount,
    );
  }

  static GenerateSecretWords fixed({required int totalCount}) {
    return GenerateSecretWords(
      max_count: totalCount,
      min_count: totalCount,
    );
  }

  int totalLength() {
    if (min_count == max_count) {
      return min_count;
    }
    return Random().nextInt(max_count - min_count + 1) + min_count;
  }
}

class Generate {
  Generate();

  static List<String> secretRandomWords({
    required int totalCount,
    required GenerateSecretWords generateSecretWords,
    String schema = "0123456789abcdefghijklmnopqrstuvwxyz",
  }) {
    List<String> secretWords = [];

    while (true) {
      if (secretWords.length == totalCount) {
        return secretWords;
      } else {
        String randomWord =
            generateUuid(generateSecretWords.totalLength(), text: schema);
        if (!secretWords.contains(randomWord)) {
          secretWords.add(randomWord);
        }
      }
    }
  }
}
